@@ -36,6 +36,7 @@ from unicodedata import normalize
 from inspire_schemas.utils import convert_old_publication_info_to_new
 from inspire_utils.helpers import force_list
 from inspire_utils.name import normalize_name, ParsedName
+from inspire_utils.query import wrap_queries_in_bool_clauses_if_more_than_one
 
 from inspire_query_parser import ast
 from inspire_query_parser.config import (
@@ -49,7 +50,6 @@ from inspire_query_parser.utils.visitor_utils import (
     generate_match_query,
     generate_nested_query,
     update_date_value_in_operator_value_pairs_for_fieldname,
-    wrap_queries_in_bool_clauses_if_more_than_one,
     wrap_query_in_nested_if_field_is_nested,
     is_initial_of_a_name,
     retokenize_first_names,
@@ -248,82 +248,9 @@ class ElasticSearchVisitor(Visitor):
         """
         parsed_name = ParsedName(author_name)
         keyword = self._get_author_or_first_author_keyword_from_fieldnames(fieldnames)
-
-        def _match_query_with_names_initials_analyzer_with_and_operator(field, value):
-            return {
-                "match": {
-                    self.KEYWORD_TO_ES_FIELDNAME[field]: {
-                        "query": value,
-                        'operator': 'AND',
-                        "analyzer": "names_initials_analyzer"
-                    }
-                }
-            }
-
-        def _match_query_with_and_operator(field, value):
-            return {
-                'match': {
-                    self.KEYWORD_TO_ES_FIELDNAME[field]: {
-                        'query': value,
-                        'operator': 'AND'
-                    }
-                }
-            }
-
-        def _match_phrase_prefix_query(field, value):
-            return {
-                "match_phrase_prefix": {
-                    self.KEYWORD_TO_ES_FIELDNAME[field]: {
-                        "query": value,
-                        "analyzer": "names_analyzer"
-                    }
-                }
-            }
-
-        if len(parsed_name) == 1 and '.' not in parsed_name.first:
-            # ParsedName returns first name if there is only one name i.e. `Smith`
-            # in our case we consider it as a lastname
-            last_name = parsed_name.first
-            query = _match_query_with_and_operator('{}_last_name'.format(keyword), last_name)
-            return self._generate_nested_author_query(query, fieldnames)
-
-        bool_query_build = []
-        bool_query_build.append(
-            _match_query_with_and_operator('{}_last_name'.format(keyword), parsed_name.last)
-        )
-
-        should_query = []
-        first_names = retokenize_first_names(parsed_name.first_list)
-        for name in first_names:
-            name_query = []
-            if is_initial_of_a_name(name):
-                name_query.append(
-                    _match_query_with_names_initials_analyzer_with_and_operator(
-                        '{}_first_name_initials'.format(keyword), name)
-                )
-            else:
-                name_query.extend([
-                    _match_phrase_prefix_query('{}_first_name'.format(keyword), name),
-                    _match_query_with_names_initials_analyzer_with_and_operator('{}_first_name'.format(keyword), name)
-                ])
-            if '.' not in parsed_name.first and ',' not in author_name:
-                name_query.append(
-                    _match_query_with_and_operator('author', author_name)
-                )
-            should_query.append(
-                wrap_queries_in_bool_clauses_if_more_than_one(
-                    name_query, use_must_clause=False)
-            )
-
-        bool_query_build.append(
-            wrap_queries_in_bool_clauses_if_more_than_one(
-                should_query, use_must_clause=True)
-        )
-
-        query = wrap_queries_in_bool_clauses_if_more_than_one(
-            bool_query_build, use_must_clause=True
-        )
-        return self._generate_nested_author_query(query, fieldnames)
+        if keyword == "first-author":
+            return parsed_name.generate_es_query(keyword="first-author")
+        return parsed_name.generate_es_query()
 
     def _generate_exact_author_query(self, author_name_or_bai):
         """Generates a term query handling authors and BAIs.
@@ -493,12 +420,15 @@ class ElasticSearchVisitor(Visitor):
             Additionally, in the aforementioned case, if a malformed date has been given, then the the method will
             return an empty dictionary.
         """
-        if self.KEYWORD_TO_ES_FIELDNAME['date'] == fieldnames:
+        if self.KEYWORD_TO_ES_FIELDNAME['date'] == fieldnames or all(
+                field in [self.KEYWORD_TO_ES_FIELDNAME['date-added'],
+                          self.KEYWORD_TO_ES_FIELDNAME['date-updated']] for field in fieldnames
+        ):
             range_queries = []
             for fieldname in fieldnames:
-                updated_operator_value_pairs = \
-                    update_date_value_in_operator_value_pairs_for_fieldname(fieldname, operator_value_pairs)
-
+                updated_operator_value_pairs = update_date_value_in_operator_value_pairs_for_fieldname(
+                    fieldname, operator_value_pairs
+                )
                 if not updated_operator_value_pairs:
                     break  # Malformed date
                 else:
@@ -650,7 +580,7 @@ class ElasticSearchVisitor(Visitor):
         return {'match_all': {}}
 
     def visit_value_op(self, node):
-        return generate_match_query('_all', node.op.value, with_operator_and=True)
+        return node.op.accept(self)
 
     def visit_malformed_query(self, node):
         return self._generate_malformed_query(node)
@@ -766,7 +696,7 @@ class ElasticSearchVisitor(Visitor):
             fieldnames=fieldnames,
             analyze_wildcard=True
         )
-        return query
+        return wrap_query_in_nested_if_field_is_nested(query, fieldnames, self.NESTED_FIELDS)
 
     def handle_author_query(self, node, fieldnames=None):
         bai_fieldnames = self._generate_fieldnames_if_bai_query(
@@ -787,17 +717,16 @@ class ElasticSearchVisitor(Visitor):
 
     def visit_value(self, node, fieldnames=None):
         if not fieldnames:
-            fieldnames = '_all'
+            return generate_match_query('_all', node.value, with_operator_and=True)
 
         if node.contains_wildcard:
             return self.handle_value_wildcard(node, fieldnames=fieldnames)
-
+        if fieldnames in [self.KEYWORD_TO_ES_FIELDNAME['date'], self.KEYWORD_TO_ES_FIELDNAME['date-added'],
+                          self.KEYWORD_TO_ES_FIELDNAME['date-updated']]:
+            # Date queries with simple values are transformed into range queries, among the given and the exact
+            # next date, according to the granularity of the given date.
+            return self._generate_range_queries(force_list(fieldnames), {ES_RANGE_EQ_OPERATOR: node.value})
         if isinstance(fieldnames, list):
-            if self.KEYWORD_TO_ES_FIELDNAME['date'] == fieldnames:
-                # Date queries with simple values are transformed into range queries, among the given and the exact
-                # next date, according to the granularity of the given date.
-                return self._generate_range_queries(force_list(fieldnames), {ES_RANGE_EQ_OPERATOR: node.value})
-
             if self.KEYWORD_TO_ES_FIELDNAME['journal'] == fieldnames:
                 return self._generate_journal_nested_queries(node.value)
 
@@ -939,7 +868,7 @@ class ElasticSearchVisitor(Visitor):
 
         return wrap_query_in_nested_if_field_is_nested(query, fieldnames, self.NESTED_FIELDS)
 
-    def visit_regex_value(self, node, fieldname):
+    def visit_regex_value(self, node, fieldname="_all"):
         query = {
             'regexp': {
                 fieldname: node.value
